@@ -6,7 +6,7 @@ Author: Saifeddine ALOUI
 Description:
 Dot perser implementation
 """
-
+from PyQt5.QtGui import QFontMetrics, QFont
 class Node():
     """
     The dot graphviz engine
@@ -21,11 +21,18 @@ class Node():
         self.in_edges=[]
         self.out_edges=[]
         self.processed = 0
-        
+
+        self.font = QFont("Arial", 12)
+        self.fm = QFontMetrics(self.font)
+
+
     @property
     def global_pos(self):
         if(self.parent_graph is not None):
-            return [self.pos[0]+self.parent_graph.pos[0], self.pos[1]+self.parent_graph.pos[1]]
+            return [
+                self.pos[0]+self.parent_graph.pos[0]-self.parent_graph.size[0]/2, 
+                self.pos[1]+self.parent_graph.pos[1]-self.parent_graph.size[1]/2
+                ]
         else:
             return self.pos
 
