@@ -186,19 +186,40 @@ class QGraphViz_Core(QWidget):
             if(self.node_removed_callback is not None):
                 self.node_removed_callback(node)
             for edge in node.in_edges:
-                del edge.source.out_edges[edge.source.out_edges.index(edge)]
+                try:
+                    del edge.source.out_edges[edge.source.out_edges.index(edge)]
+                except:
+                    pass
                 if edge.source.parent_graph == edge.dest.parent_graph:
-                    del edge.source.parent_graph.edges[edge.source.parent_graph.edges.index(edge)]
+                    try:
+                        del edge.source.parent_graph.edges[edge.source.parent_graph.edges.index(edge)]
+                    except:
+                        pass
                 else:
-                    del self.engine.graph.edges[self.engine.graph.edges.index(edge)]
+                    try:
+                        del self.engine.graph.edges[self.engine.graph.edges.index(edge)]
+                    except:
+                        pass
 
             for edge in node.out_edges:
-                del edge.source.out_edges[edge.source.out_edges.index(edge)]
+                try:
+                    del edge.source.out_edges[edge.source.out_edges.index(edge)]
+                except:
+                    pass
                 if edge.source.parent_graph == edge.dest.parent_graph:
-                    del edge.source.parent_graph.edges[edge.source.parent_graph.edges.index(edge)]
+                    try:
+                        del edge.source.parent_graph.edges[edge.source.parent_graph.edges.index(edge)]
+                    except:
+                        pass
                 else:
-                    del self.engine.graph.edges[self.engine.graph.edges.index(edge)]
-            del graph.nodes[idx]
+                    try:
+                        del self.engine.graph.edges[self.engine.graph.edges.index(edge)]
+                    except:
+                        pass
+            try:
+                del graph.nodes[idx]
+            except:
+                pass
             self.repaint()
 
     def removeSubgraph(self, subgraph):
@@ -321,13 +342,17 @@ class QGraphViz_Core(QWidget):
         return False
                     
     def findNode(self, graph, x, y):
-        for n in graph.nodes:
+        """Finds a node by position
+        """
+        for n in reversed(graph.nodes):
             if(self.isNodeHovered(n, x, y)):
                 return n
         return None
 
     def findEdge(self, graph, x, y):
-        for i,e in enumerate(graph.edges):
+        """Finds an edge by position
+        """
+        for i,e in enumerate(reversed(graph.edges)):
             if(self.isEdgeHovered(graph, i, e, x, y)):
                 return e,i
         return None,0
@@ -609,12 +634,7 @@ class QGraphViz_Core(QWidget):
             gdpos[1])
             """
 
-        if(self.show_subgraphs):
-            for node in graph.nodes:
-                if type(node)==Graph:
-                    subgraph = node
-                    self.paintSubgraph(subgraph, painter, pen, brush)
-                    
+                   
          # TODO : add more painting parameters
         for node in graph.nodes:
             if type(node)!=Graph:
@@ -767,11 +787,17 @@ class QGraphViz_Core(QWidget):
                         width, height,
                         Qt.AlignCenter|Qt.AlignTop,node.kwargs["label"])
             else:
+                subgraph = node
+                self.paintSubgraph(subgraph, painter, pen, brush)
                 if(self.show_subgraphs):
                     self.paintGraph(subgraph, painter)
-                else:
-                    subgraph = node
-                    self.paintSubgraph(subgraph, painter, pen, brush)
+        """
+        if(self.show_subgraphs):
+            for subgraph in graph.nodes:
+                if type(subgraph)==Graph:
+                    self.paintSubgraph(subgraph, painter, pen, brush)    
+                    self.paintGraph(subgraph, painter)     
+        """           
 
     def paintEvent(self, event):
         painter = QPainter(self) 
